@@ -1,23 +1,12 @@
-from typing import Any, Dict, List, Optional, Type, Union
-
-import logging
+from typing import List, Optional, Union
 
 from humps import camelize
 from pydantic import AnyUrl
 from pydantic import BaseModel as PydanticBaseModel
-from pydantic import Field, NoneStr, PositiveInt, conint, constr
+from pydantic import Field, NoneStr, PositiveInt
 
 
 class BaseModel(PydanticBaseModel):
-    # def dict(self, *args: Any, **kwargs: Any) -> Dict[str, Any]:
-    #     logging.info(kwargs)
-    #     print(kwargs)
-    #     if hasattr(kwargs, "exclude_none"):
-    #         _ignored = kwargs.pop("exclude_none")
-    #         del kwargs["exclude_none"]
-    #     print(kwargs)
-    #     return super().dict(*args, exclude_none=True, **kwargs)
-
     class Config:
         alias_generator = camelize
         allow_population_by_field_name = True
@@ -212,7 +201,7 @@ class ApiRecaster(BaseModel):
     fid: PositiveInt
     username: NoneStr = None
     display_name: NoneStr
-    recast_hash: str = Field(..., regex=r"^0[xX][0-9a-fA-F]{64}$")
+    recast_hash: str
 
 
 class Ancestors(BaseModel):
@@ -509,11 +498,6 @@ class AssetsResult(BaseModel):
     assets: List[ApiAsset]
 
 
-class CollectionAssetsGetResponse(BaseModel):
-    result: AssetsResult
-    next: Optional[Next] = None
-
-
 class CastsResult(BaseModel):
     casts: List[ApiCast]
 
@@ -550,6 +534,10 @@ class ReactionsResult(BaseModel):
     likes: List[ApiCastReaction]
 
 
+class ReactionsPutResult(BaseModel):
+    like: ApiCastReaction
+
+
 class CastReactionsGetResponse(BaseModel):
     result: ReactionsResult
     next: Optional[Next] = None
@@ -562,7 +550,7 @@ class CastReactionsPutRequest(BaseModel):
 
 
 class CastReactionsPutResponse(BaseModel):
-    result: ReactionsResult
+    result: ReactionsPutResult
 
 
 class CastReactionsDeleteRequest(BaseModel):
@@ -580,14 +568,6 @@ class CastRecastersGetResponse(BaseModel):
     next: Optional[Next] = None
 
 
-class CollectionResult(BaseModel):
-    collection: ApiAssetCollection
-
-
-class CollectionGetResponse(BaseModel):
-    result: CollectionResult
-
-
 class CollectionsResult(BaseModel):
     collections: List[ApiAssetCollection]
 
@@ -597,11 +577,6 @@ class UserCollectionsGetResponse(BaseModel):
     next: Optional[Next] = None
 
 
-class CollectionActivityGetResponse(BaseModel):
-    result: EventsResult
-    next: Optional[Next] = None
-
-
 class CollectionOwnersGetResponse(BaseModel):
     result: UsersResult
     next: Optional[Next] = None
@@ -611,12 +586,12 @@ class FollowsPutRequest(BaseModel):
     target_fid: PositiveInt
 
 
-class StatusResponse(BaseModel):
+class StatusContent(BaseModel):
     success: bool
 
 
-class StatusResultResponse(BaseModel):
-    result: StatusResponse
+class StatusResponse(BaseModel):
+    result: StatusContent
 
 
 class FollowsDeleteRequest(BaseModel):
